@@ -16,7 +16,15 @@ K <- 2
 init <- MatTrans.init(Y, K = K, n.start = 2)
 
 M <- MatTrans.EM(Y, initial = init, la = matrix(1.1,K,p),
-                 col.skew = FALSE, model = "A-EVE-VV", trans = "Power")
+  col.skew = FALSE, model = "A-EVE-VV", trans = "Power")
+
+M$best.result[[1]]$la
+
+M$best.result[[1]]$nu
+
+M$best.loglik
+
+M$best.bic
 
 
 
